@@ -1,6 +1,6 @@
 ;;; cider-client.el --- A layer of abstraction above low-level nREPL client code. -*- lexical-binding: t -*-
 
-;; Copyright © 2013-2026 Bozhidar Batsov
+;; Copyright © 2013-2025 Bozhidar Batsov
 ;;
 ;; Author: Bozhidar Batsov <bozhidar@batsov.dev>
 
@@ -175,10 +175,10 @@ Skip check if repl is active if SKIP-ENSURE is non nil."
                                                               nil
                                                             'ensure)))))
 
-(defun cider-ensure-op-supported (op &optional connection)
-  "Check for support of middleware op OP for CONNECTION.
+(defun cider-ensure-op-supported (op)
+  "Check for support of middleware op OP.
 Signal an error if it is not supported."
-  (unless (cider-nrepl-op-supported-p op connection)
+  (unless (cider-nrepl-op-supported-p op)
     (user-error "`%s' requires the nREPL op \"%s\" (provided by cider-nrepl)" this-command op)))
 
 (defun cider-nrepl-send-request (request callback &optional connection tooling)
@@ -265,17 +265,23 @@ you need to encode it as the following plist:
 If non-nil, FORMAT-OPTIONS specifies the options cljfmt will use to format
 the code.  See `cider-format-code-options' for details."
   (when format-options
-    (let* ((indents (cadr (assoc "indents" format-options)))
-           (alias-map (cadr (assoc "alias-map" format-options))))
-      (apply #'nrepl-dict
-             `(,@(when indents
-                   `("indents" ,(thread-last indents
-                                             (seq-mapcat #'identity)
-                                             (apply #'nrepl-dict))))
-               ,@(when alias-map
-                   `("alias-map" ,(thread-last alias-map
-                                               (seq-mapcat #'identity)
-                                               (apply #'nrepl-dict)))))))))
+    (let* ((indents-dict (when (assoc "indents" format-options)
+                           (thread-last
+                             (cadr (assoc "indents" format-options))
+                             (map-pairs)
+                             (seq-mapcat #'identity)
+                             (apply #'nrepl-dict))))
+           (alias-map-dict (when (assoc "alias-map" format-options)
+                             (thread-last
+                               (cadr (assoc "alias-map" format-options))
+                               (map-pairs)
+                               (seq-mapcat #'identity)
+                               (apply #'nrepl-dict)))))
+      (nrepl-dict
+       `(,@(when indents-dict
+             `("indents" ,indents-dict))
+         ,@(when alias-map-dict
+             `("alias-map" ,alias-map-dict)))))))
 
 (defcustom cider-print-fn 'pprint
   "Sets the function to use for printing.
@@ -617,12 +623,12 @@ Optional arguments include SEARCH-NS, DOCS-P, PRIVATES-P, CASE-SENSITIVE-P."
         (user-error "Invalid regexp: %s" (nrepl-dict-get response "error-msg"))
       (nrepl-dict-get response "apropos-matches"))))
 
-(defun cider-sync-request:classpath (&optional connection)
-  "Return a list of classpath entries for CONNECTION."
-  (cider-ensure-op-supported "classpath" connection)
+(defun cider-sync-request:classpath ()
+  "Return a list of classpath entries."
+  (cider-ensure-op-supported "classpath")
   (thread-first
     '("op" "classpath")
-    (cider-nrepl-send-sync-request connection)
+    (cider-nrepl-send-sync-request)
     (nrepl-dict-get "classpath")))
 
 (defun cider--get-abs-path (path project)
@@ -646,11 +652,11 @@ resolve those to absolute paths."
           (project (clojure-project-dir)))
       (mapcar (lambda (path) (cider--get-abs-path path project)) classpath))))
 
-(defun cider-classpath-entries (&optional connection)
-  "Return a list of classpath entries for CONNECTION."
+(defun cider-classpath-entries ()
+  "Return a list of classpath entries."
   (seq-map #'expand-file-name ; normalize filenames for e.g. Windows
-           (if (cider-nrepl-op-supported-p "classpath" connection)
-               (cider-sync-request:classpath connection)
+           (if (cider-nrepl-op-supported-p "classpath")
+               (cider-sync-request:classpath)
              (cider-fallback-eval:classpath))))
 
 (defun cider-sync-request:completion (prefix)
