@@ -1,7 +1,7 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "cider" "1.21.0"
+(define-package "cider" "20251018.404"
   "Clojure Interactive Development Environment that Rocks."
-  '((emacs        "28")
+  '((emacs        "27")
     (clojure-mode "5.19")
     (parseedn     "1.2.1")
     (queue        "0.2")
@@ -10,8 +10,8 @@
     (sesman       "0.3.2")
     (transient    "0.4.1"))
   :url "https://www.github.com/clojure-emacs/cider"
-  :commit "c71bc65af7709667b0cc77306f4e3d5befe86d27"
-  :revdesc "c71bc65af770"
+  :commit "5e818d32c1e5d671f0ec816d4f73446b58559c0d"
+  :revdesc "5e818d32c1e5"
   :keywords '("languages" "clojure" "cider")
   :authors '(("Tim King" . "kingtim@gmail.com")
              ("Phil Hagelberg" . "technomancy@gmail.com")
