@@ -1,7 +1,7 @@
 ;;; cider.el --- Clojure Interactive Development Environment that Rocks -*- lexical-binding: t -*-
 
-;; Copyright © 2012-2026 Tim King, Phil Hagelberg, Bozhidar Batsov
-;; Copyright © 2013-2026 Bozhidar Batsov, Artur Malabarba and CIDER contributors
+;; Copyright © 2012-2025 Tim King, Phil Hagelberg, Bozhidar Batsov
+;; Copyright © 2013-2025 Bozhidar Batsov, Artur Malabarba and CIDER contributors
 ;;
 ;; Author: Tim King <kingtim@gmail.com>
 ;;         Phil Hagelberg <technomancy@gmail.com>
@@ -14,10 +14,10 @@
 ;; Homepage: https://www.github.com/clojure-emacs/cider
 ;; Keywords: languages, clojure, cider
 ;;
-;; Package-Version: 1.21.0
-;; Package-Revision: c71bc65af770
+;; Package-Version: 20251018.404
+;; Package-Revision: 5e818d32c1e5
 ;; Package-Requires: (
-;;     (emacs "28")
+;;     (emacs "27")
 ;;     (clojure-mode "5.19")
 ;;     (parseedn "1.2.1")
 ;;     (queue "0.2")
@@ -48,8 +48,8 @@
 
 ;;; Installation:
 
-;; CIDER is available as a package in melpa.org and stable.melpa.org.  First,
-;; make sure you've enabled one of the repositories in your Emacs config:
+;; CIDER is available as a package in melpa.org and stable.melpa.org.  First, make sure you've
+;; enabled one of the repositories in your Emacs config:
 
 ;; (add-to-list 'package-archives
 ;;              '("melpa" . "https://melpa.org/packages/"))
@@ -104,10 +104,10 @@
 (require 'sesman)
 (require 'package)
 
-(defconst cider-version "1.21.0"
+(defconst cider-version "1.20.0-snapshot"
   "The current version of CIDER.")
 
-(defconst cider-codename "Gràcia"
+(defconst cider-codename "Skiathos"
   "Codename used to denote stable releases.")
 
 (defcustom cider-lein-command
@@ -115,12 +115,38 @@
   "The command used to execute Leiningen."
   :type 'string)
 
+(defcustom cider-lein-global-options
+  nil
+  "Command global options used to execute Leiningen (e.g.: -o for offline)."
+  :type 'string
+  :safe #'stringp)
+
 (defcustom cider-lein-parameters
   "repl :headless :host localhost"
   "Params passed to Leiningen to start an nREPL server via `cider-jack-in'."
   :type 'string
   :safe #'stringp)
 
+(defcustom cider-boot-command
+  "boot"
+  "The command used to execute Boot."
+  :type 'string
+  :package-version '(cider . "0.9.0"))
+
+(defcustom cider-boot-global-options
+  nil
+  "Command global options used to execute Boot (e.g.: -c for checkouts)."
+  :type 'string
+  :safe #'stringp
+  :package-version '(cider . "0.14.0"))
+
+(defcustom cider-boot-parameters
+  "repl -s -b localhost wait"
+  "Params passed to boot to start an nREPL server via `cider-jack-in'."
+  :type 'string
+  :safe #'stringp
+  :package-version '(cider . "0.9.0"))
+
 (defcustom cider-clojure-cli-command
   (if (and (eq system-type 'windows-nt)
            (null (executable-find "clojure")))
@@ -134,6 +160,13 @@ default to \"powershell\"."
   :safe #'stringp
   :package-version '(cider . "0.17.0"))
 
+(defcustom cider-clojure-cli-global-options
+  nil
+  "Command line options used to execute clojure with tools.deps."
+  :type 'string
+  :safe #'stringp
+  :package-version '(cider . "0.17.0"))
+
 (defcustom cider-clojure-cli-parameters
   nil
   "Params passed to clojure cli to start an nREPL server via `cider-jack-in'."
@@ -172,6 +205,13 @@ By default we favor the project-specific shadow-cljs over the system-wide."
   :safe #'stringp
   :package-version '(cider . "0.17.0"))
 
+(defcustom cider-shadow-cljs-global-options
+  ""
+  "Command line options used to execute shadow-cljs (e.g.: -v for verbose mode)."
+  :type 'string
+  :safe #'stringp
+  :package-version '(cider . "0.17.0"))
+
 (defcustom cider-shadow-cljs-parameters
   "server"
   "Params passed to shadow-cljs to start an nREPL server via `cider-jack-in'."
@@ -186,6 +226,13 @@ By default we favor the project-specific shadow-cljs over the system-wide."
   :safe #'stringp
   :package-version '(cider . "0.10.0"))
 
+(defcustom cider-gradle-global-options
+  ""
+  "Command line options used to execute Gradle (e.g.: -m for dry run)."
+  :type 'string
+  :safe #'stringp
+  :package-version '(cider . "0.14.0"))
+
 (defcustom cider-gradle-parameters
   "clojureRepl"
   "Params passed to gradle to start an nREPL server via `cider-jack-in'."
@@ -200,6 +247,13 @@ By default we favor the project-specific shadow-cljs over the system-wide."
   :safe #'stringp
   :package-version '(cider . "1.2.0"))
 
+(defcustom cider-babashka-global-options
+  nil
+  "Command line options used to execute Babashka."
+  :type 'string
+  :safe #'stringp
+  :package-version '(cider . "1.2.0"))
+
 (defcustom cider-babashka-parameters
   "nrepl-server localhost:0"
   "Params passed to babashka to start an nREPL server via `cider-jack-in'."
@@ -214,6 +268,13 @@ By default we favor the project-specific shadow-cljs over the system-wide."
   :safe #'stringp
   :package-version '(cider . "1.6.0"))
 
+(defcustom cider-nbb-global-options
+  nil
+  "Command line options used to execute nbb."
+  :type 'string
+  :safe #'stringp
+  :package-version '(cider . "1.6.0"))
+
 (defcustom cider-nbb-parameters
   "nrepl-server"
   "Params passed to nbb to start an nREPL server via `cider-jack-in'."
@@ -238,6 +299,17 @@ By default we favor the project-specific shadow-cljs over the system-wide."
   :safe #'stringp
   :package-version '(cider . "1.14.0"))
 
+(make-obsolete-variable 'cider-lein-global-options 'cider-lein-parameters "1.8.0")
+(make-obsolete-variable 'cider-boot-command nil "1.8.0")
+(make-obsolete-variable 'cider-boot-parameters nil "1.8.0")
+(make-obsolete-variable 'cider-boot-global-options nil "1.8.0")
+(make-obsolete-variable 'cider-clojure-cli-global-options 'cider-clojure-cli-parameters "1.8.0")
+(make-obsolete-variable 'cider-shadow-cljs-global-options 'cider-shadow-cljs-parameters "1.8.0")
+(make-obsolete-variable 'cider-gradle-global-options 'cider-gradle-parameters "1.8.0")
+(make-obsolete-variable 'cider-babashka-global-options 'cider-babashka-parameters "1.8.0")
+(make-obsolete-variable 'cider-nbb-global-options 'cider-nbb-parameters "1.8.0")
+(make-obsolete-variable 'cider-enrich-classpath nil "1.19.0")
+
 (defcustom cider-jack-in-default
   (if (executable-find "clojure") 'clojure-cli 'lein)
   "The default tool to use when doing `cider-jack-in' outside a project.
@@ -248,6 +320,7 @@ As the Clojure CLI is bundled with Clojure itself, it's the default.
 In the absence of the Clojure CLI (e.g. on Windows), we fallback
 to Leiningen."
   :type '(choice (const lein)
+                 (const boot)
                  (const clojure-cli)
                  (const shadow-cljs)
                  (const gradle)
@@ -267,6 +340,7 @@ is indicated by the variable if present.  Note, this is only when CIDER
 cannot decide which of many build systems to use and will never override a
 command when there is no ambiguity."
   :type '(choice (const lein)
+                 (const boot)
                  (const clojure-cli)
                  (const shadow-cljs)
                  (const gradle)
@@ -279,7 +353,7 @@ command when there is no ambiguity."
 
 (defcustom cider-allow-jack-in-without-project 'warn
   "Controls what happens when doing `cider-jack-in' outside a project.
-When set to `warn' (default) you'd prompted to confirm the command.
+When set to 'warn you'd prompted to confirm the command.
 When set to t `cider-jack-in' will quietly continue.
 When set to nil `cider-jack-in' will fail."
   :type '(choice (const :tag "always" t)
@@ -380,6 +454,11 @@ The plist supports the following keys
     ('basilisp    cider-basilisp-command)
     (_            (user-error "Unsupported project type `%S'" project-type))))
 
+(defcustom cider-enrich-classpath nil
+  "Removed."
+  :type 'boolean
+  :safe #'booleanp)
+
 (defun cider-jack-in-resolve-command (project-type)
   "Determine the resolved file path to `cider-jack-in-command'.
 Throws an error if PROJECT-TYPE is unknown."
@@ -406,6 +485,18 @@ Throws an error if PROJECT-TYPE is unknown."
     ('basilisp (cider--resolve-command cider-basilisp-command))
     (_ (user-error "Unsupported project type `%S'" project-type))))
 
+(defun cider-jack-in-global-options (project-type)
+  "Determine the command line options for `cider-jack-in' for the PROJECT-TYPE."
+  (pcase project-type
+    ('lein        cider-lein-global-options)
+    ('clojure-cli cider-clojure-cli-global-options)
+    ('babashka    cider-babashka-global-options)
+    ('shadow-cljs cider-shadow-cljs-global-options)
+    ('gradle      cider-gradle-global-options)
+    ('nbb         cider-nbb-global-options)
+    ('basilisp    nil)
+    (_            (user-error "Unsupported project type `%S'" project-type))))
+
 (defun cider-jack-in-params (project-type)
   "Determine the commands params for `cider-jack-in' for the PROJECT-TYPE."
   ;; The format of these command-line strings must consider different shells,
@@ -428,7 +519,7 @@ Throws an error if PROJECT-TYPE is unknown."
   "List of dependencies where elements are lists of artifact name and version.")
 (put 'cider-jack-in-dependencies 'risky-local-variable t)
 
-(defcustom cider-injected-nrepl-version "1.5.2"
+(defcustom cider-injected-nrepl-version "1.5.1"
   "The version of nREPL injected on jack-in.
 We inject the newest known version of nREPL just in case
 your version of Leiningen is bundling an older one."
@@ -609,14 +700,16 @@ ClojureNRepl task."
              middlewares
              " "))
 
-(defun cider-gradle-jack-in-dependencies (params dependencies middlewares)
+(defun cider-gradle-jack-in-dependencies (global-opts params dependencies middlewares)
   "Create gradle jack in dependencies.
-Does so by concatenating PARAMS, DEPENDENCIES,
-and MIDDLEWARES.  PARAMS are taken as-is.
+Does so by concatenating GLOBAL-OPTS, DEPENDENCIES,
+and MIDDLEWARES.  GLOBAL-OPTS and PARAMS are taken as-is.
 DEPENDENCIES are translated into Gradle's typical
 group:artifact:version notation and MIDDLEWARES are
 prepared as arguments to Clojurephant's ClojureNRepl task."
-  (concat (when cider-enable-nrepl-jvmti-agent
+  (concat global-opts
+          (unless (seq-empty-p global-opts) " ")
+          (when cider-enable-nrepl-jvmti-agent
             "-Pjdk.attach.allowAttachSelf ")
           (cider--gradle-jack-in-property (append (cider--jack-in-required-dependencies) dependencies))
           " "
@@ -637,11 +730,13 @@ of EXCLUSIONS can be provided as well.  The returned
 string is quoted for passing as argument to an inferior shell."
   (shell-quote-argument (format "[%s %S%s]" (car list) (cadr list) (cider--lein-artifact-exclusions exclusions))))
 
-(defun cider-lein-jack-in-dependencies (params dependencies dependencies-exclusions lein-plugins &optional lein-middlewares)
+(defun cider-lein-jack-in-dependencies (global-opts params dependencies dependencies-exclusions lein-plugins &optional lein-middlewares)
   "Create lein jack-in dependencies.
-Does so by concatenating DEPENDENCIES, with DEPENDENCIES-EXCLUSIONS
+Does so by concatenating GLOBAL-OPTS, DEPENDENCIES, with DEPENDENCIES-EXCLUSIONS
 removed, LEIN-PLUGINS, LEIN-MIDDLEWARES and finally PARAMS."
   (concat
+   global-opts
+   (unless (seq-empty-p global-opts) " ")
    (mapconcat #'identity
               (append (seq-map (lambda (dep)
                                  (let ((exclusions (cadr (assoc (car dep) dependencies-exclusions))))
@@ -709,12 +804,12 @@ rules to quote it."
             (concat ":" aliases)))
       "")))
 
-(defun cider-clojure-cli-jack-in-dependencies (params dependencies &optional command)
+(defun cider-clojure-cli-jack-in-dependencies (global-options params dependencies &optional command)
   "Create Clojure tools.deps jack-in dependencies.
-Does so by concatenating DEPENDENCIES and PARAMS into a suitable `clojure`
-invocation and quoting, also accounting for COMMAND if provided.  The main
-is placed in an inline alias :cider/nrepl so that if your aliases contain
-any mains, the cider/nrepl one will be the one used."
+Does so by concatenating DEPENDENCIES, PARAMS and GLOBAL-OPTIONS into a
+suitable `clojure` invocation and quoting, also accounting for COMMAND if
+provided.  The main is placed in an inline alias :cider/nrepl so that if
+your aliases contain any mains, the cider/nrepl one will be the one used."
   (let* ((all-deps (thread-last dependencies
                                 (append (cider--jack-in-required-dependencies))
                                 ;; Duplicates are never OK since they would result in
@@ -742,16 +837,20 @@ any mains, the cider/nrepl one will be the one used."
                          "")
                        main-opts))
          (deps-quoted (cider--shell-quote-argument deps command)))
-    (format "-Sdeps %s -M%s:cider/nrepl%s"
+    (format "%s-Sdeps %s -M%s:cider/nrepl%s"
+            ;; TODO: global-options are deprecated and should be removed in CIDER 2.0
+            (if global-options (format "%s " global-options) "")
             deps-quoted
             (cider--combined-aliases)
             (if params (format " %s" params) ""))))
 
-(defun cider-shadow-cljs-jack-in-dependencies (params dependencies)
+(defun cider-shadow-cljs-jack-in-dependencies (global-opts params dependencies)
   "Create shadow-cljs jack-in deps.
-Does so by concatenating PARAMS and DEPENDENCIES."
+Does so by concatenating GLOBAL-OPTS, DEPENDENCIES finally PARAMS."
   (let ((dependencies (append (cider--jack-in-required-dependencies) dependencies)))
     (concat
+     global-opts
+     (unless (seq-empty-p global-opts) " ")
      (mapconcat #'identity
                 (seq-map (lambda (dep) (format "-d %s:%s" (car dep) (cadr dep))) dependencies)
                 " ")
@@ -775,8 +874,8 @@ See also `cider-jack-in-auto-inject-clojure'."
               dependencies))
     dependencies))
 
-(defun cider-inject-jack-in-dependencies (params project-type &optional command)
-  "Return PARAMS with injected REPL dependencies.
+(defun cider-inject-jack-in-dependencies (global-opts params project-type &optional command)
+  "Return GLOBAL-OPTS and PARAMS with injected REPL dependencies.
 These are set in `cider-jack-in-dependencies', `cider-jack-in-lein-plugins'
 and `cider-jack-in-nrepl-middlewares' are injected from the CLI according
 to the used PROJECT-TYPE, and COMMAND if provided.  Eliminates the need for
@@ -784,6 +883,7 @@ hacking profiles.clj for supporting CIDER with its nREPL middleware and
 dependencies."
   (pcase project-type
     ('lein (cider-lein-jack-in-dependencies
+            global-opts
             params
             (cider-add-clojure-dependencies-maybe
              (append `(("nrepl/nrepl" ,cider-injected-nrepl-version)) cider-jack-in-dependencies))
@@ -791,21 +891,30 @@ dependencies."
             (cider-jack-in-normalized-lein-plugins)
             cider-jack-in-lein-middlewares))
     ('clojure-cli (cider-clojure-cli-jack-in-dependencies
+                   global-opts
                    params
                    (cider-add-clojure-dependencies-maybe
                     cider-jack-in-dependencies)
                    command))
-    ('babashka params)
+    ('babashka (concat
+                global-opts
+                (unless (seq-empty-p global-opts) " ")
+                params))
     ('shadow-cljs (cider-shadow-cljs-jack-in-dependencies
+                   global-opts
                    params
                    (cider-add-clojure-dependencies-maybe
                     cider-jack-in-dependencies)))
     ('gradle (cider-gradle-jack-in-dependencies
+              global-opts
               params
               (cider-add-clojure-dependencies-maybe
                cider-jack-in-dependencies)
               (cider-jack-in-normalized-nrepl-middlewares)))
-    ('nbb params)
+    ('nbb (concat
+           global-opts
+           (unless (seq-empty-p global-opts) " ")
+           params))
     ('basilisp params)
     (_ (error "Unsupported project type `%S'" project-type))))
 
@@ -1076,6 +1185,7 @@ you're working on."
                  (const :tag "Browser"  browser)
                  (const :tag "Node"     node)
                  (const :tag "Weasel"   weasel)
+                 (const :tag "Boot"     boot)
                  (const :tag "Shadow"   shadow)
                  (const :tag "Shadow w/o Server" shadow-select)
                  (const :tag "Krell"    krell)
@@ -1555,6 +1665,8 @@ PARAMS is a plist with the following keys (non-exhaustive list)
                                (cider-project-type project-dir)))
              (command (cider-jack-in-command project-type))
              (command-resolved (cider-jack-in-resolve-command project-type))
+             ;; TODO: global-options are deprecated and should be removed in CIDER 2.0
+             (command-global-opts (cider-jack-in-global-options project-type))
              (command-params (cider-jack-in-params project-type)))
         (if command-resolved
             (with-current-buffer (or (plist-get params :--context-buffer)
@@ -1565,7 +1677,7 @@ PARAMS is a plist with the following keys (non-exhaustive list)
                                                       'cider--jack-in-nrepl-params-history)
                                        command-params))
                      (cmd-params (if cider-inject-dependencies-at-jack-in
-                                     (cider-inject-jack-in-dependencies command-params
+                                     (cider-inject-jack-in-dependencies command-global-opts command-params
                                                                         project-type command)
                                    command-params)))
                 (if (or project-dir cider-allow-jack-in-without-project)
